summaryrefslogtreecommitdiffstats
path: root/ash/shell_window_ids.h
diff options
context:
space:
mode:
authorharrym@chromium.org <harrym@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-03-09 02:50:58 +0000
committerharrym@chromium.org <harrym@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-03-09 02:50:58 +0000
commit478c6c3aa0165dfd120993c5ec0757d594e70fe6 (patch)
tree3dd95bfe585e857e3672c9cfa1e705e6cdd19416 /ash/shell_window_ids.h
parent62ad3097ac2d96a2e8c65769a997702e7f0a755b (diff)
downloadchromium_src-478c6c3aa0165dfd120993c5ec0757d594e70fe6.zip
chromium_src-478c6c3aa0165dfd120993c5ec0757d594e70fe6.tar.gz
chromium_src-478c6c3aa0165dfd120993c5ec0757d594e70fe6.tar.bz2
Refactor: Shelf Widget
Refactor the classes related with displaying the shelf (background behind the launcher/status area widget) to be a separate class. Removing background delegates from the launcher and status area widget (represented on tray views). TBR=ben@chromium.org BUG=163002 Review URL: https://chromiumcodereview.appspot.com/12313118 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@187122 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/shell_window_ids.h')
-rw-r--r--ash/shell_window_ids.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ash/shell_window_ids.h b/ash/shell_window_ids.h
index 465965e..a64858f 100644
--- a/ash/shell_window_ids.h
+++ b/ash/shell_window_ids.h
@@ -53,8 +53,8 @@ const int kShellWindowId_AlwaysOnTopContainer = 7;
// The container for panel windows.
const int kShellWindowId_PanelContainer = 8;
-// The container for the launcher.
-const int kShellWindowId_LauncherContainer = 9;
+// The container for the shelf.
+const int kShellWindowId_ShelfContainer = 9;
// The container for the app list.
const int kShellWindowId_AppListContainer = 10;